Learn R Programming

ICBioMark (version 0.1.4)

ensembl_gene_lengths: Gene Lengths from the Ensembl Database

Description

Pre-imported length data from the Ensembl database for all genes on chromosomes 1-22, X and Y.

Usage

ensembl_gene_lengths

Arguments

Format

A dataframe with three columns:

Hugo_Symbol

The names of all nuclear genes in humans for which ensembl entries with coding sequence lengths exist.

max_cds

The maximum coding sequence for each gene as given by the ensembl database.

Chromosome

The chromosome where each gene is located.