Learn R Programming

ICBioMark (version 0.1.4)

get_biomarker_from_maf: Produce a Table of Biomarker Values from a MAF

Description

A function to recover true biomarker values from a mutation annotation file.

Usage

get_biomarker_from_maf(
  maf,
  biomarker = "TIB",
  sample_list = NULL,
  gene_list = NULL,
  biomarker_name = NULL
)

Arguments

maf

(dataframe) A table of annotated mutations containing the columns 'Tumor_Sample_Barcode', 'Hugo_Symbol', and 'Variant_Classification'.

biomarker

(character) Which biomarker needs calculating? If "TMB" or "TIB", then appropriate mutation types will be selected. Otherwise, will be interpreted as a vector of characters denoting mutation types to include.

sample_list

(character) Vector of characters giving a list of values of Tumor_Sample_Barcode to include.

gene_list

(character) Vector of characters giving a list of genes to include in calculation of biomarker.

biomarker_name

(character) Name of biomarker. Only needed if biomarker is not "TMB" or "TIB"

Value

A dataframe with two columns, 'Tumor_Sample_Barcode' and values of the biomarker specified.

Examples

Run this code
# NOT RUN {
print(head(get_biomarker_from_maf(example_maf_data$maf, sample_list = paste0("SAMPLE_", 1:100))))
# }

Run the code above in your browser using DataLab