(dataframe)
A table of annotated mutations containing the columns 'Tumor_Sample_Barcode', 'Hugo_Symbol', and 'Variant_Classification'.
biomarker
(character)
Which biomarker needs calculating? If "TMB" or "TIB", then appropriate mutation types will be selected. Otherwise, will be interpreted as a vector of characters
denoting mutation types to include.
sample_list
(character)
Vector of characters giving a list of values of Tumor_Sample_Barcode to include.
gene_list
(character)
Vector of characters giving a list of genes to include in calculation of biomarker.
biomarker_name
(character)
Name of biomarker. Only needed if biomarker is not "TMB" or "TIB"
tables
(list)
Optional parameter, the output of a call to get_mutation_tables(), which already has a train/val/test split.
split
(numeric)
Optional parameter directly specifying the proportions of a train/test/val split.
seed_id
(numeric)
Input value for the function set.seed().
Value
A list of three objects: 'train', 'val' and 'test. Each comprises a dataframe with two columns, denoting sample ID and biomarker value.