Learn R Programming

ICBioMark (version 0.1.4)

nsclc_survival: Non-Small Cell Lung Cancer Survival and Clinical Data

Description

A pre-loaded clinical dataset containing survival and clinical data from Campbell et. al (2016), downloaded from The Cancer Genome Atlas.

Usage

nsclc_survival

Arguments

Format

An annotated mutation dataframe with 23 columns and 1144 rows. Each row corresponds to a sample, and details clinical and survival information about the patient from whom the sample was derived. Its columns are as follows:

CASE_ID

AGE

AGE_AT_SURGERY

CANCER_TYPE

CANCER_TYPE_DETAILED

DAYS_TO_DEATH

DAYS_TO_LAST_FOLLOWUP

FRACTION_GENOME_ALTERED

HISTORY_NEOADJUVANT_TRTYN

HISTORY_OTHER_MALIGNANCY

MUTATION_COUNT

M_STAGE

N_STAGE

ONCOTREE_CODE

OS_MONTHS

OS_STATUS

SAMPLE_COUNT

SEX

SMOKING_HISTORY

SMOKING_PACK_YEARS

SOMATIC_STATUS

STAGE

T_STAGE