Pre-imported length data from the Ensembl database for all genes on chromosomes 1-22, X and Y.
ensembl_gene_lengthsA dataframe with three columns:
The names of all nuclear genes in humans for which ensembl entries with coding sequence lengths exist.
The maximum coding sequence for each gene as given by the ensembl database.
The chromosome where each gene is located.